﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;


namespace CheckBoxHeaderTest
{
    public partial class Form1 : Form
    {
        DataSet dataSet;
        DataTable dataTable;
        DataTable table = new DataTable("Holidays");

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            PopulateDataSet();
            BuildHolidayTable();
            ultraGrid1.DataSource = dataSet;
            ultraGrid2.DataSource = table;
            ultraButton1.Enabled = false;
            ultraTabControl1.Tabs[0].Selected = true; 
        }

        private void PopulateDataSet()
        {
            dataSet = new DataSet();
            dataTable = new DataTable("Customer");
            dataTable.Columns.Add("Selected", typeof(bool)); 
            dataTable.Columns.Add("CustomerName", typeof(string));
            dataTable.Columns.Add("Date", typeof(DateTime));
            dataTable.Columns.Add("City", typeof(string));
            dataTable.Columns.Add("State", typeof(string));

            dataTable.Rows.Add(new object[] { true, "John Lever", DateTime.Now, "New York", "NY" });
            dataTable.Rows.Add(new object[] { false, "Walter Smith", DateTime.Now.AddDays(1), "Jersey City", "NJ" });
            dataTable.Rows.Add(new object[] { true, "Kathy Lever", DateTime.Now.AddDays(2), "Newark", "NJ" });
            dataTable.Rows.Add(new object[] { false, "George Wills", DateTime.Now.AddDays(3), "Trenton", "NJ" });

            dataSet.Tables.Add(dataTable);

        }

        private void BuildHolidayTable()
        {
            DataColumn col = new DataColumn("Holiday", System.Type.GetType("System.String"));
            table.Columns.Add(col);

            col = new DataColumn("Date", System.Type.GetType("System.DateTime"));
            table.Columns.Add(col);

            DataRow row = table.NewRow();
            row["Holiday"] = "New Year's Day";
            row["Date"] = "01/01/2008";
            table.Rows.Add(row);

            DataRow row2 = table.NewRow();
            row2["Holiday"] = "George Washington's Birthday";
            row2["Date"] = "02/22/2008";
            table.Rows.Add(row2);

            DataRow row3 = table.NewRow();
            row3["Holiday"] = "May Day";
            row3["Date"] = "05/01/2010";
            table.Rows.Add(row3);

            DataRow row4 = table.NewRow();
            row4["Holiday"] = "First of Ramadan";
            row4["Date"] = "08/11/2010";
            table.Rows.Add(row4);
        }

        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Header.CheckBoxVisibility = HeaderCheckBoxVisibility.Always;
            e.Layout.Bands[0].Columns[0].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;
        }

        private void ultraGrid1_AfterHeaderCheckStateChanged(object sender, AfterHeaderCheckStateChangedEventArgs e)
        {
            Debug.WriteLine("------------------------------------------------------------------------------------");
            Debug.Indent();
            Debug.WriteLine("ultraGrid1_AfterHeaderCheckStateChanged");
            Debug.WriteLine(string.Format("Column Key: {0}", e.Column.Key));
            Debug.Unindent();
        }

        private void ultraButton1_Click(object sender, EventArgs e)
        {
            MessageBox.Show("Sauvez!");
        }

        private void ultraButton2_Click(object sender, EventArgs e)
        {
            MessageBox.Show("Rescue me!");
        }

        private void ultraTabControl1_SelectedTabChanged(object sender, Infragistics.Win.UltraWinTabControl.SelectedTabChangedEventArgs e)
        {
            if (ultraTabControl1.SelectedTab.Index == 0)
            {
                ultraGrid2.Focus();
            }
            else
                if (ultraTabControl1.SelectedTab.Index == 1)
                {
                    ultraGrid1.Focus();
                }
            Debug.WriteLine("------------------------------------------------------------------------------------");
            Debug.Indent();
            Debug.WriteLine("ultraTabControl1_SelectedTabChanged");
            Debug.WriteLine(string.Format("Selected Tab Index: {0}", e.Tab.Index));
            Debug.WriteLine(string.Format("Selected Tab Key: {0}", e.Tab.Key));
            Debug.Unindent();
        }

        private void ultraTabControl1_Enter(object sender, EventArgs e)
        {
            ultraGrid1.Focus();
        }

       
    }
}
